function overall
% 
% LICENSE CONDITIONS
% ==================================
% 
% Copyright   2011   The Regents of the University of California
% All Rights Reserved
% 
% Permission to use, copy, modify and distribute any part of this 
% code for Boosting Algorithms for Simultaneous Feature Extraction and 
% Selection for educational, research 
% and non-profit purposes, without fee, and without a written 
% agreement is hereby granted, provided that the above copyright 
% notice, this paragraph and the following three paragraphs appear 
% in all copies.
% 
% Those desiring to incorporate this code for TaylorBoost, SOPBoost and 
% POSBoost into commercial products or use for commercial purposes 
% should contact the Technology Transfer & Intellectual Property 
% Services, University of California, San Diego, 9500 Gilman Drive, 
% Mail Code 0910, La Jolla, CA 92093-0910, Ph: (858) 534-5815, 
% FAX: (858) 534-7345, E-MAIL:invent@ucsd.edu.
% 
% IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE 
% TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, 
% OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, 
% ARISING OUT OF THE USE OF THIS CODE FOR TAYLOR, SOP, POS - BOOST
% EVEN IF THE UNIVERSITY OF CALIFORNIA 
% HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
% 
% THE CODE FOR TAYLOR, SOP, POS BOOST PROVIDED 
% HEREIN IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF 
% CALIFORNIA HAS NO OBLIGATION TO PROVIDE MAINTENANCE, 
% SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.  
% THE UNIVERSITY OF CALIFORNIA MAKES NO REPRESENTATIONS 
% AND EXTENDS NO WARRANTIES OF ANY KIND, EITHER IMPLIED 
% OR EXPRESS, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
% WARRANTIES OF MERCHANTABILITY OR FITNESS FOR 
% A PARTICULAR PURPOSE, OR THAT THE USE OF THE 
% CODE FORTAYLOR, SOP, POS BOOST WILL NOT 
% INFRINGE ANY PATENT, TRADEMARK OR OTHER RIGHTS.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Please cite the following papers if you are using this code:
%   
%   Boosting Algorithms for Simultaneous Feature Extraction and Selection
%   Mohammad J. Saberian and Nuno Vasconcelos .
%   Proc. IEEE Conference on Computer Vision and Pattern Recognition (CVPR),
%   Providence, RI, 2012
%
%   TaylorBoost: First and Second Order Boosting Algorithms with Explicit Margin Control
%   Mohammad J. Saberian, Hamed Masnadi-Shirazi and Nuno Vasconcelos .
%   Proc. IEEE Conference on Computer Vision and Pattern Recognition (CVPR),
%   Colorado Springs, CO, 2011.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is a matlab function that implements SOP,POS,Lin + TaylorBoost for a toy data set 
% using regression weak learners. 
% 
% inputs: 
%
% Tf: number of iterations
% These variables are  in train_'S' and test_'S' files
% XF: is the training set where each row is one traingin example
% Y: is the label of examples
% XFv and Yv are the test sets
% f: is the feature matrix where i^th feature is Hi=XF*f(:,i);
% Type: select 'G' for gradient (First order) and 'N' for Newton method  (Second order) 
% L_Type: select the type of loss function 


Tf=20;                          % number of iterations
step=1;                         % look at findbestmatlab.m

n=5;                            % No effect in this version
C=0.5;                          % No effect in this version
Z=0.5;                          % No effect in this version

%%%%%% Select Boosting order %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Type='G';                     % use first order Boosting, Gradinet descent
Type='N';                       % use second order Boosting, Newton Method

%%%%% Select loss function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% L_Type='Exp';                 % use exponential loss
L_Type='Log';                   % use logistic loss
% L_Type='Lap';                 % use laplacian loss
% L_Type='CBL';                 % use canonical boosting loss

%%%%%%%%%%% Loading data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S='synt';
loc='Data';
load([loc '/train_' S]);
load([loc '/test_' S]);             % data matrix is XF, if [m,n] = size(XF)
                                    % m is numbr of examples and n is
                                    % dimension of each one.
f=eye(size(XF,2));                  % f is feature matrix. Feature are 
                                    % extracted using XF*f. You may use
                                    % more complicated feature matrix.
%%%%%%%%%%% select the weak learner combination method %%%%%%%%%%%%%%%%%%%%
err_SOP=main_SOP(XF,Y,XFv,Yv,S,step,C,Z,Tf,1,f,Type,L_Type);
% err_Lin=main_Lin(XF,Y,XFv,Yv,S,step,C,Z,Tf,1,f,Type,L_Type);
% err_POS=main_POS(XF,Y,XFv,Yv,S,step,C,Z,Tf,1,f,Type,L_Type);


    